@@ -78,6 +78,7 @@ using namespace std;
 -I directory      Add directory to search for included source files.\n\
 -L directory      Add directory to search for dynamic libraries.\n\
 -l libname        Library to be linked in batch compilation.\n\
+-mopt=val         Add llc machine options in batch compilation.\n\
 --main=name       Name of main entry point in batch compilation.\n\
 --noediting       Disable command-line editing.\n\
 --noprelude, -n   Do not load the prelude.\n\
@@ -216,6 +217,7 @@ main(int argc, char *argv[])
   string outname = "a.out";
 #endif
   list<string> libnames;
+  string llcopts;
   // This is used in advisory stack checks.
   interpreter::baseptr = &base;
   // We always ignore SIGPIPE by default.
@@ -414,6 +416,18 @@ main(int argc, char *argv[])
 	  s = *args;
 	}
 	libnames.push_back(unixize(s));
+      } else if (strncmp(*args, "-m", 2) == 0) {
+	string s = string(*args).substr(2);
+	if (s.empty()) {
+	  interp.error(prog + ": -m lacks option argument");
+	  return 1;
+	}
+	if (llcopts.empty())
+	  llcopts = *args;
+	else {
+	  llcopts += " ";
+	  llcopts += *args;
+	}
       } else if (strncmp(*args, "-I", 2) == 0) {
 	string s = string(*args).substr(2);
 	if (s.empty()) {
@@ -550,7 +564,8 @@ main(int argc, char *argv[])
     else {
       if (interp.compiling || interp.verbose&verbosity::dump)
 	interp.compile();
-      if (interp.compiling) status = interp.compiler(outname, libnames);
+      if (interp.compiling)
+	status = interp.compiler(outname, libnames, llcopts);
       //printf("status = %d\n", status);
     }
     /* interp.compiler() apparently leaves the code module in a dangling
